@@ -7,14 +7,13 @@ from .improve_dlc_output import improve_dlc_output
 from .csv_utils import concat_csv, csv2h5
 from .analyze_rois import analyze_rois
 from .concat_rois import concat_rois
-from .json2tidycsv import json2tidycsv
-from .obtain_grand_m import obtain_grand_m
 from .dlcboxplot import dlcboxplot
 from .fwarnings import fwarnings
 from .combine_dlc_improved import combine_dlc_improved
 from .analyze_turnpoints import analyze_turnpoints
 from .return_sem import return_sem
 from .sniff_boxplot import sniff_boxplot
-from .MannWhitney_U import MannWhitney_U
+from .MannWhitney_U import *
+from .data_utils import json2tidycsv, obtain_grand_m, jsonify_dlc_avgs
 
 from .version import __version__, VERSION
